@@ -1,20 +1,9 @@
 /*
-  Copyright 2010 BetterInbox <contact@betterinbox.com>
-      Author: Christophe Laveault <christophe@betterinbox.com>
-              Gregory Schlomoff <gregory.schlomoff@gmail.com>
+  SPDX-FileCopyrightText: 2010 BetterInbox <contact@betterinbox.com>
+  SPDX-FileContributor: Christophe Laveault <christophe@betterinbox.com>
+  SPDX-FileContributor: Gregory Schlomoff <gregory.schlomoff@gmail.com>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Lesser General Public
-  License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Lesser General Public License for more details.
-
-  You should have received a copy of the GNU Lesser General Public
-  License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+  SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #ifndef KSMTP_SESSIONTHREAD_P_H
@@ -79,7 +68,7 @@ private:
     Session *m_parentSession = nullptr;
     QString m_hostName;
     quint16 m_port;
-    bool m_useProxy;
+    bool m_useProxy = false;
 };
 }
 
